==> tioga-notify-engine-1.1.0-sources.jar: org/tiogasolutions/notify/engine/v1/ClientResourceV1.java <==
package org.tiogasolutions.notify.engine.v1;

import org.tiogasolutions.dev.common.exceptions.ApiNotFoundException;
import org.tiogasolutions.notify.kernel.event.EventBus;
import org.tiogasolutions.notify.kernel.domain.DomainKernel;
import org.tiogasolutions.notify.kernel.execution.ExecutionManager;
import org.tiogasolutions.notify.kernel.notification.NotificationKernel;
import org.tiogasolutions.notify.pub.domain.DomainProfile;
import org.tiogasolutions.notify.pub.domain.DomainSummary;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

public class ClientResourceV1 {

  private final EventBus eventBus;
  private final DomainKernel domainKernel;
  private final ExecutionManager executionManager;
  private final NotificationKernel notificationKernel;

  public ClientResourceV1(ExecutionManager executionManager, DomainKernel domainKernel, NotificationKernel notificationKernel, EventBus eventBus) {
    this.eventBus = eventBus;
    this.domainKernel = domainKernel;
    this.executionManager = executionManager;
    this.notificationKernel = notificationKernel;
  }

  @GET
  @Produces({MediaType.APPLICATION_JSON})
  public DomainProfile getDefaultPage() {
    String domainName = executionManager.context().getDomainName();
    return domainKernel.findByDomainName(domainName);
  }

  @GET
  @Path("summary")
  @Produces({MediaType.APPLICATION_JSON})
  public Response getDomainSummary() {
    try {
      String domainName = executionManager.context().getDomainName();
      DomainSummary summary = domainKernel.fetchSummary(domainName);
      return Response.ok(summary).build();

    } catch(ApiNotFoundException e) {
      return Response.status(404).entity(e).build();
    }
  }

  @Path("/notifications")
  public NotificationsResourceV1 getNotificationsResource() {
    return new NotificationsResourceV1(executionManager, notificationKernel);
  }

  @Path("/route-catalog")
  public RouteCatalogResourceV1 getRouteCatalogResource() {
    return new RouteCatalogResourceV1(executionManager, domainKernel);
  }

  @Path("/requests")
  public NotificationRequestResourceV1 getRequestResourceV1() {
    return new NotificationRequestResourceV1(executionManager, domainKernel, eventBus);
  }

  @Path("/simple-request-entry")
  public SimpleRequestEntryResourceV1 getSimpleRequestEntryV1() {
    return new SimpleRequestEntryResourceV1(executionManager, domainKernel, eventBus);
  }
}

==> tioga-notify-engine-1.1.6-sources.jar: org/tiogasolutions/notify/engine/v1/ClientResourceV1.java <==
package org.tiogasolutions.notify.engine.v1;

import org.tiogasolutions.dev.common.exceptions.ApiNotFoundException;
import org.tiogasolutions.notify.kernel.event.EventBus;
import org.tiogasolutions.notify.kernel.domain.DomainKernel;
import org.tiogasolutions.notify.kernel.execution.ExecutionManager;
import org.tiogasolutions.notify.kernel.notification.NotificationKernel;
import org.tiogasolutions.notify.pub.domain.DomainProfile;
import org.tiogasolutions.notify.pub.domain.DomainSummary;

import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

public class ClientResourceV1 {

  private final EventBus eventBus;
  private final DomainKernel domainKernel;
  private final ExecutionManager executionManager;
  private final NotificationKernel notificationKernel;

  public ClientResourceV1(ExecutionManager executionManager, DomainKernel domainKernel, NotificationKernel notificationKernel, EventBus eventBus) {
    this.eventBus = eventBus;
    this.domainKernel = domainKernel;
    this.executionManager = executionManager;
    this.notificationKernel = notificationKernel;
  }

  @GET
  @Produces({MediaType.APPLICATION_JSON})
  public DomainProfile getDomainProfile() {
    String domainName = executionManager.context().getDomainName();
    return domainKernel.findByDomainName(domainName);
  }

  @GET
  @Path("sign-in")
  @Produces({MediaType.APPLICATION_JSON})
  public DomainProfile signIn() {
    return getDomainProfile();
  }

  @GET
  @Path("summary")
  @Produces({MediaType.APPLICATION_JSON})
  public Response getDomainSummary() {
    try {
      String domainName = executionManager.context().getDomainName();
      DomainSummary summary = domainKernel.fetchSummary(domainName);
      return Response.ok(summary).build();

    } catch(ApiNotFoundException e) {
      return Response.status(404).entity(e).build();
    }
  }

  @Path("/notifications")
  public NotificationsResourceV1 getNotificationsResource() {
    return new NotificationsResourceV1(executionManager, notificationKernel);
  }

  @Path("/route-catalog")
  public RouteCatalogResourceV1 getRouteCatalogResource() {
    return new RouteCatalogResourceV1(executionManager, domainKernel);
  }

  @Path("/requests")
  public NotificationRequestResourceV1 getRequestResourceV1() {
    return new NotificationRequestResourceV1(executionManager, domainKernel, eventBus);
  }

  @Path("/simple-request-entry")
  public SimpleRequestEntryResourceV1 getSimpleRequestEntryV1() {
    return new SimpleRequestEntryResourceV1(executionManager, domainKernel, eventBus);
  }
}
